@@ -104,7 +104,7 @@ char disable_ae2_alias;
 /*
  * analyzer.c
  */
-unsigned int default_flags; /* from analyzer.c 5 */
+TraceFlagsType default_flags; /* from analyzer.c 5 */
 unsigned int default_fpshift;
 Times tims; /* from analyzer.c 6 */
 Traces traces; /* from analyzer.c 7 */
@@ -349,6 +349,14 @@ unsigned stem_valid : 1;
 unsigned istem_valid : 1;
 char *fst_synclock_str;
 JRB synclock_jrb;
+#ifdef _WAVE_HAVE_JUDY
+Pvoid_t *xl_enum_filter;
+#else
+struct xl_tree_node **xl_enum_filter;
+#endif
+int num_xl_enum_filter;
+fstEnumHandle queued_xl_enum_filter;
+JRB enum_nptrs_jrb;
 
 
 /*
@@ -848,7 +856,7 @@ GtkWidget *toggle4_showchange_c_1; /* from showchange.c 391 */
 GtkWidget *window_showchange_c_8; /* from showchange.c 392 */
 void (*cleanup_showchange_c_6)(void); /* from showchange.c 393 */
 struct TraceEnt *tcache_showchange_c_1; /* from showchange.c 394 */
-unsigned int flags_showchange_c_1; /* from showchange.c 395 */
+TraceFlagsType flags_showchange_c_1; /* from showchange.c 395 */
 
 
 /*
@@ -1166,6 +1174,7 @@ off_t vcd_fsiz_vcd_c_1; /* from vcd.c 549 */
 char *varsplit_vcd_c_1; /* from vcd.c 550 */
 char *vsplitcurr_vcd_c_1; /* from vcd.c 551 */
 int var_prevch_vcd_c_1; /* from vcd.c 552 */
+char vcd_already_backtracked;
 
 
 /*
