@@ -108,7 +108,7 @@ for(;;s++)
 }
 
 
-static lxtint64_t vcd_prevtime;
+static lxtint64_t vcd_prevtime = LXT2_RD_ULLDESC(~0);
 char vcd_blackout = 0;
 static int backtrack_warning = 0;
 
@@ -120,7 +120,7 @@ struct lxt2_rd_geometry *g = lxt2_rd_get_fac_geometry(*lt, *pnt_facidx);
 
 if(vcd_prevtime != *pnt_time)
 	{
-	if((vcd_prevtime > *pnt_time) && (!backtrack_warning) && (vcd_prevtime != -1))
+	if((vcd_prevtime > *pnt_time) && (!backtrack_warning) && (vcd_prevtime != LXT2_RD_ULLDESC(~0)))
 		{
 		backtrack_warning = 1;
 		fprintf(stderr, "LXTLOAD | Time backtracking encountered: this VCD might load incorrectly in gtkwave.\n");
@@ -198,23 +198,23 @@ if(lt)
                 case 0:         time_dimension = 's'; break;
 
                 case -1:        time_scale = 100; 		time_dimension = 'm'; break;
-                case -2:        time_scale = 10;
+                case -2:        time_scale = 10; /* fallthrough */
                 case -3:                                        time_dimension = 'm'; break;
 
                 case -4:        time_scale = 100; 		time_dimension = 'u'; break;
-                case -5:        time_scale = 10;
+                case -5:        time_scale = 10; /* fallthrough */
                 case -6:                                        time_dimension = 'u'; break;
 
                 case -10:       time_scale = 100; 		time_dimension = 'p'; break;
-                case -11:       time_scale = 10;
+                case -11:       time_scale = 10; /* fallthrough */
                 case -12:                                       time_dimension = 'p'; break;
 
                 case -13:       time_scale = 100; 		time_dimension = 'f'; break;
-                case -14:       time_scale = 10;
+                case -14:       time_scale = 10; /* fallthrough */
                 case -15:                                       time_dimension = 'f'; break;
 
                 case -7:        time_scale = 100; 		time_dimension = 'n'; break;
-                case -8:        time_scale = 10;
+                case -8:        time_scale = 10; /* fallthrough */
                 case -9:
                 default:                                        time_dimension = 'n'; break;
                 }
