@@ -111,7 +111,7 @@ return(GLOBALS->buf_menu_c_1);
 void write_save_helper(const char *savnam, FILE *wave) {
 	Trptr t;
 	int i;
-	unsigned int def=0;
+	TraceFlagsType def=0;
 	int sz_x, sz_y;
 	TimeType prevshift=LLDescriptor(0);
 	int root_x, root_y;
@@ -255,7 +255,7 @@ void write_save_helper(const char *savnam, FILE *wave) {
 			if((t->flags & TR_PTRANSLATED) && (!t->p_filter)) t->flags &= (~TR_PTRANSLATED);
 			if((t->flags & TR_FTRANSLATED) && (!t->f_filter)) t->flags &= (~TR_FTRANSLATED);
 			if((t->flags & TR_TTRANSLATED) && (!t->t_filter)) t->flags &= (~TR_TTRANSLATED);
-			fprintf(wave,"@%x\n",def=t->flags);
+			fprintf(wave,"@%"TRACEFLAGSPRIFMT"\n",def=t->flags);
 			}
 
 		if((t->shift)||((prevshift)&&(!t->shift)))
@@ -366,7 +366,7 @@ void write_save_helper(const char *savnam, FILE *wave) {
 						}
 					if(ba)
 						{
-						fprintf(wave, " "TTFormat" %x", ba[ix].shift, ba[ix].flags);
+						fprintf(wave, " "TTFormat" %"TRACEFLAGSPRIFMT, ba[ix].shift, ba[ix].flags);
 						}
 					}
 				fprintf(wave,"\n");
@@ -443,7 +443,7 @@ void write_save_helper(const char *savnam, FILE *wave) {
 					if((t->flags & TR_FTRANSLATED) && (!t->f_filter)) t->flags &= (~TR_FTRANSLATED);
 					if((t->flags & TR_PTRANSLATED) && (!t->p_filter)) t->flags &= (~TR_PTRANSLATED);
 					if((t->flags & TR_TTRANSLATED) && (!t->t_filter)) t->flags &= (~TR_TTRANSLATED);
-					fprintf(wave,"@%x\n",def=t->flags);
+					fprintf(wave,"@%"TRACEFLAGSPRIFMT"\n",def=t->flags);
 					}
 
 				if((t->shift)||((prevshift)&&(!t->shift)))
@@ -535,7 +535,7 @@ void write_save_helper(const char *savnam, FILE *wave) {
 								}
 							if(ba)
 								{
-								fprintf(wave, " "TTFormat" %x", ba[ix].shift, ba[ix].flags);
+								fprintf(wave, " "TTFormat" %"TRACEFLAGSPRIFMT, ba[ix].shift, ba[ix].flags);
 								}
 							}
 						fprintf(wave,"\n");
@@ -1124,7 +1124,7 @@ else
 if(*w2=='@')
 	{
 	/* handle trace flags */
-	sscanf(w2+1, "%x", &GLOBALS->default_flags);
+	sscanf(w2+1, "%"TRACEFLAGSSCNFMT, &GLOBALS->default_flags);
 	if( (GLOBALS->default_flags & (TR_FTRANSLATED|TR_PTRANSLATED)) == (TR_FTRANSLATED|TR_PTRANSLATED) )
 		{
 		GLOBALS->default_flags &= ~TR_PTRANSLATED; /* safest bet though this is a cfg file error */
@@ -2423,7 +2423,7 @@ if(s)
 #endif
 
 
-char *find_dumpfile(char *orig_save, char *orig_dump, char *this_save)
+char *find_dumpfile_2(char *orig_save, char *orig_dump, char *this_save)
 {
 char *synth_nam = NULL;
 
@@ -2481,6 +2481,33 @@ if(orig_save && orig_dump && this_save)
 return(synth_nam);
 }
 
+
+char *find_dumpfile(char *orig_save, char *orig_dump, char *this_save)
+{
+char *dfile = NULL;
+
+dfile = find_dumpfile_2(orig_save, orig_dump, this_save);
+if(!dfile && orig_save && orig_dump)
+        {
+	const char *pfx = "/././";
+        int pfxlen = strlen(pfx);
+        char *orig_save2 = malloc_2(strlen(orig_save) + pfxlen + 1);
+        char *orig_dump2 = malloc_2(strlen(orig_dump) + pfxlen + 1);
+
+	strcpy(orig_save2, pfx); strcat(orig_save2, orig_save);
+        strcpy(orig_dump2, pfx); strcat(orig_dump2, orig_dump);
+
+        dfile = find_dumpfile_2(orig_save2, orig_dump2, this_save);
+        if(!dfile)
+                {
+                free_2(orig_dump2);
+                free_2(orig_save2);
+                }
+        }
+
+return(dfile);
+}
+
 /******************************************************************/
 
 /*
