@@ -112,6 +112,23 @@ Tcl_SetObjResult(interp, aobj);
 return(TCL_OK);
 }
 
+static int gtkwavetcl_printTraceFlagsType(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[], TraceFlagsType ttVal)
+{
+(void)clientData;
+(void)objc;
+(void)objv;
+
+Tcl_Obj *aobj;
+char reportString[65];
+
+sprintf(reportString, "%"TRACEFLAGSPRIuFMT, ttVal);
+
+aobj = Tcl_NewStringObj(reportString, -1);
+Tcl_SetObjResult(interp, aobj);
+
+return(TCL_OK);
+}
+
 static int gtkwavetcl_printDouble(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[], double dVal)
 {
 (void)clientData;
@@ -495,7 +512,7 @@ if(objc == 2)
 			{
 			if(i == which)
 				{
-				return(gtkwavetcl_printInteger(clientData, interp, objc, objv, t->flags));
+				return(gtkwavetcl_printTraceFlagsType(clientData, interp, objc, objv, t->flags));
 				}
 
 			i++;
@@ -1790,7 +1807,7 @@ if(objc == 2)
 
 	if(t)
 		{
-		return(gtkwavetcl_printInteger(clientData, interp, objc, objv, t->flags));
+		return(gtkwavetcl_printTraceFlagsType(clientData, interp, objc, objv, t->flags));
 		}
 	}
         else
@@ -2035,7 +2052,7 @@ if(objc == 2)
         {
         char *s = get_Tcl_string(objv[1]);
         unsigned int which = atoi(s);
-	gint rc = install_file_filter(which);
+	gint rc = install_proc_filter(which);
 
         gtkwave_main_iteration();
 	return(gtkwavetcl_printInteger(clientData, interp, objc, objv, rc));
